==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/text.h <==
// Fetch-on-demand cache for texts.
//
// $Id: text.h,v 1.25 1995/11/18 22:50:28 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_TEXT_H
#define KOMXX_TEXT_H

#include <limits.h>
#include "text-cache.h"
#include "LyStr.h"
#include "fetchable.h"

class Session;
class Connection;
class Text_mass_cache;


class Text : public Fetchable {
  public:
    Text();
    Text(Text_no, Text_stat_cache *, Text_mass_cache *);
    Text(const Text &);
    ~Text();

    const Text & operator = (const Text &);

    Status   	prefetch() 	 const;
    bool	present() 	 const;
    bool	exists() 	 const;
    int		errno()		 const;
    Text_no     text_no()        const;

    // Prefetch everything that is needed by nilkom to display this
    // text, but issue at most max_questions questions. Return the
    // number of pending questions, or -1 if a hard error occurs.
    int		prefetch_for_display(int max_questions, 
				     Session *sess) const;

    // Accessors to the various parts of the data.
    struct tm   creation_time()  const;
    Pers_no	author() 	 const;
    long        num_lines()      const;
    long        num_chars()      const;
    int         num_marks()      const;
    int         num_recipients() const;
    Recipient*  recipient(int)   const;
    int		num_comment_in() const;
    Text_no	comment_in(int)	 const;
    int		num_footnote_in()const;
    Text_no	footnote_in(int) const;
    int		num_uplinks()	 const;
    Uplink*	uplink(int)	 const;

    LyStr	text_mass(long start=0, long end=LONG_MAX) const;
    // subject() and body() can be used to retriev only the subject
    // and body of the text.  The arguments to body() are relative to
    // the body, so they are NOT the same numbers as in text_mass().
    LyStr       subject() const;
    LyStr       body(long start=0, long end=LONG_MAX) const;

    // Utility functions. These might be quite costly, so
    // take care when using them.
    Status      mark_as_read(Conf_no confno = 0);
    Status      mark(unsigned char mark_type = 255);
    Status      unmark();

    // If CONF_NO is a recipient of this text, return the
    // Local_text_no it has. Otherwise, or if an error occurs, return
    // 0.
    Local_text_no  local_no_recipient(Conf_no conf_no);

  private:
    Text_no tno;
    Text_stat_cache *ts_cache;
    Text_mass_cache *tm_cache;
};



class Texts {
  public:
    Texts(Connection *c, Async_dispatcher *async_disp);
    ~Texts();

    Text  operator[](Text_no);

    Text_stat_cache * read_text_stat_cache() const;
    Text_mass_cache * read_text_mass_cache() const;

  private:
    Texts(const Texts &);
    const Texts & operator = (const Texts &);

    Connection      * connection;
    Text_stat_cache * ts_cache;
    Text_mass_cache * tm_cache;
};


#endif

==> kom%2B%2B-0.6.tar.gz: kom++-0.6/libkom++/text.h <==
// Fetch-on-demand cache for texts.
//
// $Id: text.h,v 1.29 1996/07/17 19:19:38 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_TEXT_H
#define KOMXX_TEXT_H

#include <limits.h>
#include "text-cache.h"
#include "LyStr.h"
#include "LyStr-errno.h"
#include "fetchable.h"

class Session;
class Connection;
class Text_mass_cache;


class Text : public Fetchable {
  public:
    Text();
    Text(Text_no, Text_stat_cache *, Text_mass_cache *);
    Text(const Text &);
    ~Text();

    const Text & operator = (const Text &);

    Status   	prefetch() 	 const;
    Status      prefetch_text()  const;
    bool        prefetch_pending() const;
    bool	present() 	 const;
    bool	exists() 	 const;
    int		errno()		 const;
    Text_no     text_no()        const;

    // Prefetch everything that is needed by nilkom to display this
    // text, but issue at most max_questions questions. Return the
    // number of pending questions, or -1 if a hard error occurs.
    int		prefetch_for_display(int max_questions, 
				     Session *sess) const;

    // Accessors to the various parts of the data.
    struct tm   creation_time()  const;
    Pers_no	author() 	 const;
    long        num_lines()      const;
    long        num_chars()      const;
    int         num_marks()      const;
    int         num_recipients() const;
    Recipient*  recipient(int)   const;
    int		num_comment_in() const;
    Text_no	comment_in(int)	 const;
    int		num_footnote_in()const;
    Text_no	footnote_in(int) const;
    int		num_uplinks()	 const;
    Uplink*	uplink(int)	 const;

    LyStr_errno	text_mass(long begin=0, long end=LONG_MAX) const;
    // subject() and body() can be used to retriev only the subject
    // and body of the text.  The arguments to body() are relative to
    // the body, so they are NOT the same numbers as in text_mass().
    LyStr_errno subject() const;
    LyStr_errno body(long begin=0, long end=LONG_MAX) const;

    // Returns the time when this text was entered in the specified
    // conference with the specified local number.  This is most of
    // the time equal to creation_time(), but it may differ if this
    // text was added to the conference at a later time.
    struct tm   entry_time(Conf_no, Local_text_no);

    // Utility functions. These might be quite costly, so
    // take care when using them.
    Status      mark_as_read(Conf_no confno = 0);
    Kom_err     mark(unsigned char mark_type = 255);
    Kom_err     unmark();

    // If CONF_NO is a recipient of this text, return the
    // Local_text_no it has. Otherwise, or if an error occurs, return
    // 0.
    Local_text_no  local_no_recipient(Conf_no conf_no);

  private:
    Text_no tno;
    Text_stat_cache *ts_cache;
    Text_mass_cache *tm_cache;
};



class Texts {
  public:
    Texts(Connection *c, Async_dispatcher *async_disp);
    ~Texts();

    Text  operator[](Text_no);

    Text_stat_cache * read_text_stat_cache() const;
    Text_mass_cache * read_text_mass_cache() const;

  private:
    Texts(const Texts &);
    const Texts & operator = (const Texts &);

    Connection      * connection;
    Text_stat_cache * ts_cache;
    Text_mass_cache * tm_cache;
};


#endif
